==> python_usajobsapi-0.3.0.tar.gz: python_usajobsapi-0.3.0/CHANGELOG.md <==
# CHANGELOG

<!-- version list -->

## v0.3.0 (2025-10-09)

### Chores

- **ci**: Show renovate confidence badges in PRs
  ([`e4601b0`](https://github.com/paddy74/python-usajobsapi/commit/e4601b09560a84c3f4aaeaf2ca1003680416f727))

### Continuous Integration

- Configure renovatebot
  ([`9c1f3fc`](https://github.com/paddy74/python-usajobsapi/commit/9c1f3fc12179afdcce191ad549e590c3e75a276c))

- Define codecov config file
  ([`77dc1f8`](https://github.com/paddy74/python-usajobsapi/commit/77dc1f8e05b43b4a3ec1103cb2abc90b99f22450))

- Replace check-json hook with check-json5
  ([`dae5e58`](https://github.com/paddy74/python-usajobsapi/commit/dae5e58336ecda771a687b70a081c9bcc55ec23e))

- Trigger patch release for fix,build,perf commits
  ([`3f856d5`](https://github.com/paddy74/python-usajobsapi/commit/3f856d58cbc84f13f9b4405380eace875356df8f))

- Trigger patch releases on renovatebot user deps upgrades
  ([`be09249`](https://github.com/paddy74/python-usajobsapi/commit/be09249f25ce7a38017fece88a90e931abed82d0))

- **fix**: Add missing checkout to paths-filter
  ([`9b82077`](https://github.com/paddy74/python-usajobsapi/commit/9b820779040dee07150ba284a73f10f7f2fa79d7))

- **fix**: Fix nested ci ref to secrets.CODECOV_TOKEN
  ([`72813f7`](https://github.com/paddy74/python-usajobsapi/commit/72813f7dccf384275f3e980afd83cf6a4e8c3725))

- **tests**: Add coverage reports and upload to codecov
  ([#15](https://github.com/paddy74/python-usajobsapi/pull/15),
  [`b76f614`](https://github.com/paddy74/python-usajobsapi/commit/b76f6143afcaceb7f15d1309de32fcdb29fcf50c))

### Documentation

- Supplement project property documents
  ([#18](https://github.com/paddy74/python-usajobsapi/pull/18),
  [`334c1b3`](https://github.com/paddy74/python-usajobsapi/commit/334c1b38dd6135a2f5cdb67a0046a5086da0777e))

- **core**: Document with mkdocs and github pages
  ([#14](https://github.com/paddy74/python-usajobsapi/pull/14),
  [`64ed1dc`](https://github.com/paddy74/python-usajobsapi/commit/64ed1dc3826847b54738f8e0e94541259d2145c9))

- **fix**: Fix and cleanup documentation
  ([#21](https://github.com/paddy74/python-usajobsapi/pull/21),
  [`f1629f0`](https://github.com/paddy74/python-usajobsapi/commit/f1629f0bdf963e65498058456a97bbe1d6719949))

### Features

- Implement command line executable ([#22](https://github.com/paddy74/python-usajobsapi/pull/22),
  [`dc12a44`](https://github.com/paddy74/python-usajobsapi/commit/dc12a44d93040efddc460b1da3a56c783063f12b))


## v0.2.0 (2025-09-30)

### Features

- **api**: Support the job search api endpoint
  ([#9](https://github.com/paddy74/python-usajobsapi/pull/9),
  [`1295a3e`](https://github.com/paddy74/python-usajobsapi/commit/1295a3eb3b00c26c90f91e80e271fab14c10eedb))


## v0.1.0 (2025-09-26)

### Features

- **api**: Support the historic joa api endpoint
  ([#12](https://github.com/paddy74/python-usajobsapi/pull/12),
  [`02ea27b`](https://github.com/paddy74/python-usajobsapi/commit/02ea27b2cb1b65b95b78c22604cc16832b834eb0))


## v0.0.1 (2025-09-22)

- Initial Release

==> python_usajobsapi-1.0.1.tar.gz: python_usajobsapi-1.0.1/CHANGELOG.md <==
# CHANGELOG

<!-- version list -->

## v1.0.1 (2025-10-13)

### Bug Fixes

- **ci**: Use patch releases for fix,build,perf tags
  ([`c3e1df7`](https://github.com/paddy74/python-usajobsapi/commit/c3e1df796bd25c6d4523f3b1b54604b859e61d7c))

### Build System

- **deps**: Upgrade dependencies
  ([`aa48153`](https://github.com/paddy74/python-usajobsapi/commit/aa481532b8ea5841d678226c763054edf24df9a9))

- **deps**: Use external dist of mkdocs-extrafiles
  ([`9675c6b`](https://github.com/paddy74/python-usajobsapi/commit/9675c6bfa2539bfd4e9957d8145c00b450fde652))


## v1.0.0 (2025-10-09)

### Features

- Commit version 1.0.0
  ([`5487c07`](https://github.com/paddy74/python-usajobsapi/commit/5487c0723e5aa796d0b1a5580ce2b13978ed2ce8))


## v0.3.0 (2025-10-09)

### Chores

- **ci**: Show renovate confidence badges in PRs
  ([`e4601b0`](https://github.com/paddy74/python-usajobsapi/commit/e4601b09560a84c3f4aaeaf2ca1003680416f727))

### Continuous Integration

- Configure renovatebot
  ([`9c1f3fc`](https://github.com/paddy74/python-usajobsapi/commit/9c1f3fc12179afdcce191ad549e590c3e75a276c))

- Define codecov config file
  ([`77dc1f8`](https://github.com/paddy74/python-usajobsapi/commit/77dc1f8e05b43b4a3ec1103cb2abc90b99f22450))

- Replace check-json hook with check-json5
  ([`dae5e58`](https://github.com/paddy74/python-usajobsapi/commit/dae5e58336ecda771a687b70a081c9bcc55ec23e))

- Trigger patch release for fix,build,perf commits
  ([`3f856d5`](https://github.com/paddy74/python-usajobsapi/commit/3f856d58cbc84f13f9b4405380eace875356df8f))

- Trigger patch releases on renovatebot user deps upgrades
  ([`be09249`](https://github.com/paddy74/python-usajobsapi/commit/be09249f25ce7a38017fece88a90e931abed82d0))

- **fix**: Add missing checkout to paths-filter
  ([`9b82077`](https://github.com/paddy74/python-usajobsapi/commit/9b820779040dee07150ba284a73f10f7f2fa79d7))

- **fix**: Fix nested ci ref to secrets.CODECOV_TOKEN
  ([`72813f7`](https://github.com/paddy74/python-usajobsapi/commit/72813f7dccf384275f3e980afd83cf6a4e8c3725))

- **tests**: Add coverage reports and upload to codecov
  ([#15](https://github.com/paddy74/python-usajobsapi/pull/15),
  [`b76f614`](https://github.com/paddy74/python-usajobsapi/commit/b76f6143afcaceb7f15d1309de32fcdb29fcf50c))

### Documentation

- Supplement project property documents
  ([#18](https://github.com/paddy74/python-usajobsapi/pull/18),
  [`334c1b3`](https://github.com/paddy74/python-usajobsapi/commit/334c1b38dd6135a2f5cdb67a0046a5086da0777e))

- **core**: Document with mkdocs and github pages
  ([#14](https://github.com/paddy74/python-usajobsapi/pull/14),
  [`64ed1dc`](https://github.com/paddy74/python-usajobsapi/commit/64ed1dc3826847b54738f8e0e94541259d2145c9))

- **fix**: Fix and cleanup documentation
  ([#21](https://github.com/paddy74/python-usajobsapi/pull/21),
  [`f1629f0`](https://github.com/paddy74/python-usajobsapi/commit/f1629f0bdf963e65498058456a97bbe1d6719949))

### Features

- Implement command line executable ([#22](https://github.com/paddy74/python-usajobsapi/pull/22),
  [`dc12a44`](https://github.com/paddy74/python-usajobsapi/commit/dc12a44d93040efddc460b1da3a56c783063f12b))


## v0.2.0 (2025-09-30)

### Features

- **api**: Support the job search api endpoint
  ([#9](https://github.com/paddy74/python-usajobsapi/pull/9),
  [`1295a3e`](https://github.com/paddy74/python-usajobsapi/commit/1295a3eb3b00c26c90f91e80e271fab14c10eedb))


## v0.1.0 (2025-09-26)

### Features

- **api**: Support the historic joa api endpoint
  ([#12](https://github.com/paddy74/python-usajobsapi/pull/12),
  [`02ea27b`](https://github.com/paddy74/python-usajobsapi/commit/02ea27b2cb1b65b95b78c22604cc16832b834eb0))


## v0.0.1 (2025-09-22)

- Initial Release
